@@ -1,5 +1,5 @@
 package HTML::Spelling::Site::Checker;
-$HTML::Spelling::Site::Checker::VERSION = '0.4.1';
+$HTML::Spelling::Site::Checker::VERSION = '0.4.2';
 use strict;
 use warnings;
 use autodie;
@@ -167,7 +167,7 @@ s{\A(?:(?:ֹו?(?:ש|ל|מ|ב|כש|לכש|מה|שה|לכשה|ב-))|ו)-?}{};
             handlers    => [
                 start => [ sub { return $self->_tag(@_); }, "tagname, '+1'" ],
                 end   => [ sub { return $self->_tag(@_); }, "tagname, '-1'" ],
-                text => [ $process_text, "dtext" ],
+                text  => [ $process_text,                   "dtext" ],
             ],
             marked_sections => 1,
         )->parse_file($fh);
@@ -240,9 +240,13 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+HTML::Spelling::Site::Checker - does the actual checking.
+
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
@@ -402,10 +406,6 @@ In t/html-spell-check.t :
 The instances of this class can be used to do the actual scanning of
 local HTML files.
 
-=head1 NAME
-
-HTML::Spelling::Site::Checker - does the actual checking.
-
 =head1 METHODS
 
 =head2 my $obj = HTML::Spelling::Site::Checker->new({ whitelist_parser => $parser_obj, check_word_cb => sub { ... }, timestamp_cache_fn => '/path/to/timestamp-cache.json' })
@@ -444,7 +444,7 @@ For internal use.
 
 For internal use.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -481,14 +481,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Spelling-Site>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/HTML-Spelling-Site>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
